@@ -20,11 +20,11 @@ Geocoder is an Apache2 Licensed Geocoding library, written in Python.
 """
 
 __title__ = 'geocoder'
-__version__ = '0.5.9'
+__version__ = '0.6.0'
 __author__ = 'Denis Carriere'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2014 Denis Carriere'
 
 
 from api import arcgis, bing, geonames, google, mapquest, nokia, osm, tomtom
-from api import get, population, reverse, ip
\ No newline at end of file
+from api import get, population, reverse, ip, elevation
