@@ -33,6 +33,10 @@ class Base(object):
     county = None
     state = None
     ip = None
+    status = None
+    short_name = None
+    elevation = None
+    resolution = None
 
     def __init__(self):
         self.json = dict()
